==> fastutil-6.3-sources.jar: it/unimi/dsi/fastutil/floats/FloatIndirectPriorityQueue.java <==
/* Generic definitions */




/* Assertions (useful to generate conditional code) */
/* Current type and class (and size, if applicable) */
/* Value methods */
/* Interfaces (keys) */
/* Interfaces (values) */
/* Abstract implementations (keys) */
/* Abstract implementations (values) */
/* Static containers (keys) */
/* Static containers (values) */
/* Implementations */
/* Synchronized wrappers */
/* Unmodifiable wrappers */
/* Other wrappers */
/* Methods (keys) */
/* Methods (values) */
/* Methods (keys/values) */
/* Methods that have special names depending on keys (but the special names depend on values) */
/* Equality */
/* Object/Reference-only definitions (keys) */
/* Primitive-type-only definitions (keys) */
/* Object/Reference-only definitions (values) */
/*		 
 * Copyright (C) 2003-2011 Paolo Boldi and Sebastiano Vigna 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */
package it.unimi.dsi.fastutil.floats;
import it.unimi.dsi.fastutil.IndirectPriorityQueue;
/** A type-specific {@link IndirectPriorityQueue}. 
 *
 * <P>Additionally, this interface strengthens {@link #comparator()}.
 */
public interface FloatIndirectPriorityQueue extends IndirectPriorityQueue<Float> {
    /** Returns the comparator associated with this queue.
	 *
	 * Note that this specification strengthens the one given in {@link IndirectPriorityQueue}.
	 *
	 * @return the comparator associated with this queue.
	 * @see IndirectPriorityQueue#comparator()
	 */
 FloatComparator comparator();
}

==> fastutil-7.0.12-sources.jar: it/unimi/dsi/fastutil/floats/FloatIndirectPriorityQueue.java <==
/* Generic definitions */
/* Assertions (useful to generate conditional code) */
/* Current type and class (and size, if applicable) */
/* Value methods */
/* Interfaces (keys) */
/* Interfaces (values) */
/* Abstract implementations (keys) */
/* Abstract implementations (values) */
/* Static containers (keys) */
/* Static containers (values) */
/* Implementations */
/* Synchronized wrappers */
/* Unmodifiable wrappers */
/* Other wrappers */
/* Methods (keys) */
/* Methods (values) */
/* Methods (keys/values) */
/* Methods that have special names depending on keys (but the special names depend on values) */
/* Equality */
/* Object/Reference-only definitions (keys) */
/* Primitive-type-only definitions (keys) */
/* Object/Reference-only definitions (values) */
/*		 
 * Copyright (C) 2003-2016 Paolo Boldi and Sebastiano Vigna
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */
package it.unimi.dsi.fastutil.floats;
import it.unimi.dsi.fastutil.IndirectPriorityQueue;
/**
 * A type-specific {@link IndirectPriorityQueue}.
 *
 * <P>
 * Additionally, this interface strengthens {@link #comparator()}.
 */
public interface FloatIndirectPriorityQueue
		extends
			IndirectPriorityQueue<Float> {
	/**
	 * Returns the comparator associated with this queue.
	 *
	 * Note that this specification strengthens the one given in
	 * {@link IndirectPriorityQueue}.
	 *
	 * @return the comparator associated with this queue.
	 * @see IndirectPriorityQueue#comparator()
	 */
	FloatComparator comparator();
}
